#!/usr/bin/env python
from setuptools import setup

setup(
    name='django_cron_tasks',
    description='Django background tasks, ran via crontab.',
    version='1.0.0',
    packages=['django_cron_tasks'],
    author='Henrik Heino',
    author_email='henrik.heino@gmail.com',
    license='MIT License',
    url='https://github.com/henu/django_cron_tasks',
)
